@@ -28,4 +28,18 @@ sub crossover {
 	}
 }
 
+### complement of 2 genomes (xor)
+sub genome_complement {
+	my ($self, $inputgenome) = @_;
+	
+	my $returngenome = BitGenome->new; 
+
+	for (my $i = 0; $i < scalar $self->{genes}; $i++) {
+		$returngenome->add_to( 
+			$inputgenome->{genes}[$i] ^ $self->{genes}[$i]);
+	}
+
+	return $returngenome;
+}
+
 1;
